﻿using System;

using DevExpress.Data.PivotGrid;
using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraEditors.Repository;
using DevExpress.XtraPivotGrid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 저장소 항목 진행바
        /// </summary>
        private RepositoryItemProgressBar repositoryItemProgressBar = new RepositoryItemProgressBar();

        /// <summary>
        /// 저장소 항목 스핀 에디터
        /// </summary>
        private RepositoryItemSpinEdit repositoryItemSpinEdit = new RepositoryItemSpinEdit();

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.tableAdapter.Fill(this.nwindDataSet.SalesPerson);

            this.quantityPercentField.SummaryDisplayType      = PivotSummaryDisplayType.PercentOfColumn;
            this.quantityPercentField.CellFormat.FormatType   = FormatType.Custom;
            this.quantityPercentField.CellFormat.FormatString = "{0}%";

            this.pivotGridControl.RepositoryItems.AddRange
            (
                new RepositoryItem[]
                {
                    this.repositoryItemProgressBar,
                    this.repositoryItemSpinEdit
                }
            );
            
            this.pivotGridControl.CustomCellEdit  += pivotGridControl_CustomCellEdit;
            this.pivotGridControl.CustomCellValue += pivotGridControl_CustomCellValue;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 피벗 그리드 컨트롤 셀 에디터 커스텀 설정하기 - pivotGridControl_CustomCellEdit(sender, e)

        /// <summary>
        /// 피벗 그리드 컨트롤 셀 에디터 커스텀 설정하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void pivotGridControl_CustomCellEdit(object sender, PivotCustomCellEditEventArgs e)
        {
            if(e.DataField == this.quantityPercentField)
            {
                if(e.RowValueType == PivotGridValueType.Value)
                {
                    e.RepositoryItem = this.repositoryItemProgressBar;
                }

                if(e.RowValueType == PivotGridValueType.GrandTotal)
                {
                    e.RepositoryItem = this.repositoryItemSpinEdit;
                }
            }
        }

        #endregion
        #region 피벗 그리드 컨트롤 셀 값 커스텀 설정하기 - pivotGridControl_CustomCellValue(sender, e)

        /// <summary>
        /// 피벗 그리드 컨트롤 셀 값 커스텀 설정하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void pivotGridControl_CustomCellValue(object sender, PivotCellValueEventArgs e)
        {
            if(e.DataField == this.quantityPercentField)
            {
                e.Value = Convert.ToDecimal(e.Value) * 100;
            }
        }

        #endregion
    }
}